@@ -44,4 +44,13 @@ class BadBoardResponseError(AssertionError):
     """
     The board replied with an unexpected format
     """
-    pass
\ No newline at end of file
+    pass
+
+
+class BoardBenchmarkAlreadyExists(AssertionError):
+    """
+    The given board benchmark already exists
+    """
+    def __init__(self, key):
+        message = 'A benchmark record for [%s] already exists' % str(key)
+        super().__init__(message)
\ No newline at end of file
