@@ -1,5 +1,5 @@
 import numpy as np
-from sklearn.model_selection import KFold, train_test_split
+from sklearn.model_selection import KFold
 from eloquentarduino.ml.data import Dataset
 
 
