@@ -11,7 +11,7 @@ class ConfusionMatrix:
         self.y_pred = y_pred
         self.labels = labels or [str(i) for i in range(min(self.y_true), max(self.y_true) + 1)]
 
-    def show(self, normalize=None, cmap='viridis', xticks_rotation=70, **kwargs):
+    def show(self, title=None, normalize=None, cmap='viridis', xticks_rotation=70, **kwargs):
         """
         Draw matrix
         :param normalize: bool
@@ -20,5 +20,9 @@ class ConfusionMatrix:
         """
         cm = confusion_matrix(self.y_true, self.y_pred, normalize=normalize)
         disp = ConfusionMatrixDisplay(confusion_matrix=cm, display_labels=self.labels)
+        cf = disp.plot(include_values=True, cmap=cmap, xticks_rotation=xticks_rotation, **kwargs)
 
-        return disp.plot(include_values=True, cmap=cmap, xticks_rotation=xticks_rotation, **kwargs)
\ No newline at end of file
+        if title is not None:
+            cf.ax_.set_title(title)
+
+        return cf
\ No newline at end of file
