@@ -1,7 +1,9 @@
 import matplotlib.pyplot as plt
 from eloquentarduino.plot.Bar import Bar
 from eloquentarduino.plot.ConfusionMatrix import ConfusionMatrix
+from eloquentarduino.plot.DimensionalityReductionPlotter import DimensionalityReductionPlotter
 from eloquentarduino.plot.PCAPlotter import PCAPlotter
+from eloquentarduino.plot.TSNEPlotter import TSNEPlotter
 from eloquentarduino.plot.RankMatrix import RankMatrix
 
 
